<?php
/*
Plugin Name: BuddyPress Last Comments Widget
Author: Inna Z
Description: Shows a list of most recently added BP activity comments.
Version: 1.2
Created on: 26.09.2017
*/

/* Start Adding Functions Below this Line */

// Register and load the widget
function bp_last_comments_load_widget() {
    register_widget( 'bp_last_comments_widget' );
}
add_action( 'widgets_init', 'bp_last_comments_load_widget' );

// Get SQL records from DB
function bp_get_recent_comments($number_blogs)
{
	global $wpdb;

	$recent_blogs = $wpdb->get_results( "SELECT user_id, content, item_id, id, date_recorded FROM {$wpdb->prefix}bp_activity WHERE TYPE = 'activity_comment' ORDER BY date_recorded DESC LIMIT $number_blogs" );
	return $recent_blogs;
 
 }
 
 // Draw html line for each comment
 function bp_show_recent_comments($number_blogs)
 {
	$recent_blogs = bp_get_recent_comments($number_blogs);
					
	foreach($recent_blogs as $recent_blog):
		$domain = get_option('siteurl');
		$blog_url = $domain."/activity/p/".$recent_blog->item_id ."/#acomment-".$recent_blog->id;
		$blog_content = $recent_blog->content;
		mb_internal_encoding("UTF-8");
?>
			<li><a href="<?php echo $blog_url;?>"><?php echo mb_substr(esc_attr($blog_content), 0, 60); ?></a></li>
<?php 
	endforeach;
 } 
 
// Creating the widget 
class bp_last_comments_widget extends WP_Widget { 
	
	// Constructor
	function __construct() {
		parent::__construct(
		 
		// Base ID of your widget
		'bp_last_comments_widget', 
		 
		// Widget name will appear in UI
		__('(BuddyPress) Last Comments Widget', 'bp_last_comments_widget_domain'), 
		 
		// Widget description
		array( 'description' => __( 'BP widget based on last activity comments', 'bp_last_comments_widget_domain' ), ) 
		);
	}
	 
	// Creating Frontend widget	 
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );
		 
		// before and after widget arguments are defined by themes
		echo $args['before_widget'];
		if ( ! empty( $title ) )
			echo $args['before_title'] . $title . $args['after_title'];
		 
		// This is where you run the code and display the output
		echo "<ul>";
		bp_show_recent_comments($instance['count']);
		echo "</ul>";
		
		echo $args['after_widget'];
	}
			 
	// Widget Backend (admin) widget
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'New title', 'bp_last_comments_widget_domain' );
		}
		$count = absint( $instance['count'] );
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e( 'Number of comments:' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo esc_attr( absint( $count ) ); ?>" />
		</p>
	<?php 
	}
		 
	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = absint($new_instance['count'] ) ;

		return $instance;
	}
} // Class bp_last_comments_widget ends here
 
/* Stop Adding Functions Below this Line */
?>